package com.example.kaveh.feature.main.adapter

import android.content.Context
import android.content.Intent
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.core.content.ContentProviderCompat.requireContext
import androidx.core.content.ContextCompat.startActivity
import androidx.recyclerview.widget.RecyclerView
import com.example.kaveh.R
import com.example.kaveh.common.EXTRA_KEY_DATA
import com.example.kaveh.common.implementSpringAnimationTrait
import com.example.kaveh.data.entity.category.SubCategory
import com.example.kaveh.feature.places.CategoryDetailsActivity
import com.example.kaveh.services.ImageLoadingService
import com.example.kaveh.view.KavehImageView
import kotlin.coroutines.coroutineContext

class CategorySubListAdapter(val imageLoadingService: ImageLoadingService,
                             val category: List<SubCategory>,
                             val categoryItemId : Int,
                             
) : RecyclerView.Adapter<CategorySubListAdapter.ViewHolder>() {



    var onCategoryClickListener: OnCategoryClickListener? = null


    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        return ViewHolder(
            LayoutInflater.from(parent.context).inflate(R.layout.item_sub_category,parent,false)
        )
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) = holder.bindCategory(category[position])

    override fun getItemCount(): Int = category.size

    inner class ViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {

        val categoryIv: KavehImageView = itemView.findViewById(R.id.imageCategorySubItem)
        val titleTv: TextView = itemView.findViewById(R.id.textCategorySubTitle)


        fun bindCategory(category: SubCategory) {
            imageLoadingService.load(categoryIv, category.sub_category_url)
            titleTv.text = category.sub_category_name

            itemView.implementSpringAnimationTrait()
            itemView.setOnClickListener {
                itemView.run {
                     onCategoryClickListener?.onCategoryClick(category,categoryItemId)

                }
            }
        }
    }

    interface OnCategoryClickListener {
        fun onCategoryClick(category: SubCategory,categoryItemId: Int)
    }


}